ChangeBatch

Struct ChangeBatch 

pub struct ChangeBatch { /* private fields */ }
One atomic post-commit subscription event.

Implementations

Source

impl ChangeBatch

pub const fn commit_id(&self) -> CommitId

Returns the immutable source commit.

pub const fn sequence(&self) -> u64

Returns the monotonically increasing local-author sequence.

pub fn frontier(&self) -> &[CommitId]

Returns the complete local domain frontier after this batch was applied.

pub fn changes(&self) -> &[Change]

Returns all record effects published atomically by the commit.