pub struct DomainSeed { /* private fields */ }Expand description
Sensitive bootstrap material for adding a new device to an encrypted domain.
Implementations
Sourceimpl DomainSeed
impl DomainSeed
Sourcepub fn generate() -> Result<DomainSeed, SecurityError>
pub fn generate() -> Result<DomainSeed, SecurityError>
Creates a fresh encrypted domain seed.
Sourcepub fn domain_key(&self) -> DomainKey
pub fn domain_key(&self) -> DomainKey
Returns the epoch-zero key for a trusted local key provider.
Sourcepub fn next_epoch(&self) -> Result<DomainSeed, SecurityError>
pub fn next_epoch(&self) -> Result<DomainSeed, SecurityError>
Creates the next epoch for this stable domain using a fresh random key.
Sourcepub fn distribution_digest(&self) -> [u8; 32]
pub fn distribution_digest(&self) -> [u8; 32]
Returns a non-secret commitment used to bind targeted key distribution to control.