pub struct InvitationTicket { /* private fields */ }Expand description
An encrypted offline invitation envelope safe to store without its bearer secret.
Implementations
Sourceimpl InvitationTicket
impl InvitationTicket
Sourcepub fn open(
&self,
secret: &InvitationSecret,
local_subject: AuthorId,
) -> Result<Invitation, InvitationError>
pub fn open( &self, secret: &InvitationSecret, local_subject: AuthorId, ) -> Result<Invitation, InvitationError>
Decrypts and validates a ticket for exactly the local endpoint identity.
Sourcepub fn encode_canonical(&self) -> Result<Vec<u8>, InvitationError>
pub fn encode_canonical(&self) -> Result<Vec<u8>, InvitationError>
Strictly encodes the opaque ticket.
Sourcepub fn id(&self) -> Result<[u8; 32], InvitationError>
pub fn id(&self) -> Result<[u8; 32], InvitationError>
Returns the content identifier used for durable one-time import consumption.
Sourcepub fn decode_canonical(
bytes: &[u8],
) -> Result<InvitationTicket, InvitationError>
pub fn decode_canonical( bytes: &[u8], ) -> Result<InvitationTicket, InvitationError>
Strictly decodes an opaque ticket without attempting decryption.