pub struct IrohSigner { /* private fields */ }Expand description
The iroh endpoint signing identity used by the database protocol.
Implementations
Sourceimpl IrohSigner
impl IrohSigner
Sourcepub fn generate() -> IrohSigner
pub fn generate() -> IrohSigner
Generates a new iroh endpoint identity.
Sourcepub fn from_secret_bytes(bytes: [u8; 32]) -> IrohSigner
pub fn from_secret_bytes(bytes: [u8; 32]) -> IrohSigner
Imports deterministic endpoint secret bytes from a trusted key provider.
Sourcepub const fn new(secret_key: SecretKey) -> IrohSigner
pub const fn new(secret_key: SecretKey) -> IrohSigner
Wraps the same iroh secret key used by an endpoint.
Returns the authenticated iroh endpoint identity.
Sourcepub fn sign(&self, canonical_commit_bytes: &[u8]) -> [u8; 64]
pub fn sign(&self, canonical_commit_bytes: &[u8]) -> [u8; 64]
Signs canonical commit bytes under the commit-specific context.
Sourcepub fn sign_snapshot(&self, canonical_snapshot_bytes: &[u8]) -> [u8; 64]
pub fn sign_snapshot(&self, canonical_snapshot_bytes: &[u8]) -> [u8; 64]
Signs canonical snapshot bytes under a snapshot-specific context.
Sourcepub fn sign_backup_catalog(&self, canonical_catalog_bytes: &[u8]) -> [u8; 64]
pub fn sign_backup_catalog(&self, canonical_catalog_bytes: &[u8]) -> [u8; 64]
Signs a canonical backup catalog under a backup-specific context.
Sourcepub fn sign_gossip(&self, canonical_hint_bytes: &[u8]) -> [u8; 64]
pub fn sign_gossip(&self, canonical_hint_bytes: &[u8]) -> [u8; 64]
Signs a bounded gossip hint under a gossip-specific protocol context.
Sourcepub fn sign_capability(&self, canonical_authority_bytes: &[u8]) -> [u8; 64]
pub fn sign_capability(&self, canonical_authority_bytes: &[u8]) -> [u8; 64]
Signs canonical domain-authority bytes under a capability-specific context.
Sourcepub fn sign_domain_descriptor(
&self,
canonical_descriptor_bytes: &[u8],
) -> [u8; 64]
pub fn sign_domain_descriptor( &self, canonical_descriptor_bytes: &[u8], ) -> [u8; 64]
Signs canonical genesis bytes under a descriptor-specific context.
Sourcepub fn sign_invitation(&self, canonical_invitation_bytes: &[u8]) -> [u8; 64]
pub fn sign_invitation(&self, canonical_invitation_bytes: &[u8]) -> [u8; 64]
Signs a targeted invitation under an invitation-specific context.
Signs a history-compacting authority checkpoint.
Sourcepub fn sign_control(&self, canonical_control_bytes: &[u8]) -> [u8; 64]
pub fn sign_control(&self, canonical_control_bytes: &[u8]) -> [u8; 64]
Signs a domain control transition under a control-specific context.