pub struct Lww<T> { /* private fields */ }Expand description
A causal last-writer-wins register that never uses wall-clock time.
Implementations
Sourceimpl<T> Lww<T>
impl<T> Lww<T>
Sourceimpl<T> Lww<T>
impl<T> Lww<T>
Sourcepub fn assign(
&mut self,
value: T,
dot: Dot,
context: VersionVector,
) -> Result<(), CrdtError>
pub fn assign( &mut self, value: T, dot: Dot, context: VersionVector, ) -> Result<(), CrdtError>
Applies an assignment using causal order, then dot order for concurrency.
Sourcepub fn merge(&mut self, other: &Lww<T>) -> Result<(), CrdtError>
pub fn merge(&mut self, other: &Lww<T>) -> Result<(), CrdtError>
Deterministically combines another replica’s state.
Sourcepub fn canonicalize_for_commit(
&self,
author: AuthorId,
sequence: u64,
context: &VersionVector,
next_operation: &mut u32,
) -> Result<Lww<T>, CrdtError>
pub fn canonicalize_for_commit( &self, author: AuthorId, sequence: u64, context: &VersionVector, next_operation: &mut u32, ) -> Result<Lww<T>, CrdtError>
Reissues causal metadata from an authenticated commit while preserving the value.