pub struct OrderedList<T> { /* private fields */ }Expand description
A replicated growable ordered list with stable element dots.
Implementations
Sourceimpl<T> OrderedList<T>
impl<T> OrderedList<T>
Sourceimpl<T> OrderedList<T>
impl<T> OrderedList<T>
Sourcepub fn insert_after(
&mut self,
parent: Option<Dot>,
dot: Dot,
value: T,
) -> Result<(), CrdtError>
pub fn insert_after( &mut self, parent: Option<Dot>, dot: Dot, value: T, ) -> Result<(), CrdtError>
Inserts a stable element after parent, or at the replicated root.
Sourcepub fn remove(
&mut self,
dot: Dot,
context: &VersionVector,
) -> Result<(), CrdtError>
pub fn remove( &mut self, dot: Dot, context: &VersionVector, ) -> Result<(), CrdtError>
Removes an element that is visible in context.
Sourcepub fn merge(&mut self, other: &OrderedList<T>) -> Result<(), CrdtError>
pub fn merge(&mut self, other: &OrderedList<T>) -> Result<(), CrdtError>
Deterministically combines another replica’s state.
Sourcepub fn canonicalize_for_commit(
&self,
author: AuthorId,
sequence: u64,
_context: &VersionVector,
next_operation: &mut u32,
) -> Result<OrderedList<T>, CrdtError>
pub fn canonicalize_for_commit( &self, author: AuthorId, sequence: u64, _context: &VersionVector, next_operation: &mut u32, ) -> Result<OrderedList<T>, CrdtError>
Rebuilds the visible sequence with commit-owned element identities.